@@ -38,7 +38,7 @@ GetSequences <- function(ProteinAccList, directorypath = NULL){
     #to see if Request == 200 or not
     Request <- tryCatch(
       {
-        GET(paste0(baseUrl , ProteinAcc,".xml") , timeout(7))
+        GET(paste0(baseUrl , ProteinAcc,".xml"))
       },error = function(cond)
       {
         message("Internet connection problem occurs and the function will return the original error")
